<?php

/**
 * Users endpoint
 * /v1/users
 *
 * @author 
 */

/**
 * Load configuration
 */
require_once('../../config.php');

/**
 * Load models
 */
require_once '../../lib/ModelBaseInterface.php';            // base interface class for RedBean models
require_once '../../lib/Model_Customers.php';               // customer model

require_once "../../includes/CommonFunctions.php";

/**
 * Library objects
 */
use RedBean_Facade as R;
use Helpers\RedBeanHelper as RedBeanHelper;
use Helpers\PasswordHelper as PasswordHelper;
use Enumerations\HttpStatusCode as HttpStatusCode;
use Exceptions\ApiException as ApiException;
use Enumerations\AccountType as AccountType;
use Enumerations\StatusType as StatusType;
use Enumerations\ErrorCodeType as ErrorCodeType;
/**
 * Initialize application
 */
beaconApi::init(true);
$app = new \Slim\Slim();


/**
 * New user creation
 * POST /v1/customers
 */
$app->post('/', function () use ($app) {

    try {

        // Create a http request
        $req = $app->request();

        /**
         * Get a new user account
         * @var Model_Customers $user
         */
        $customer				= R::dispense('customers');
		$customer->FirstName 	= $req->params('FirstName');
		$customer->LastName 	= $req->params('LastName');
		$customer->Email 		= $req->params('Email');
		$customer->Password 	= $req->params('Password');
	    /**
         * Create the account
         */
	    $customerId = $customer->create();
        /**
         * New user creation was made success
         */
		if($customerId != ''){
	        $response = new beaconApiResponse();
	        $response->setStatus(HttpStatusCode::Created);
	        $response->meta->dataPropertyName = 'customer';
			/**
	        * returning upon repsonse of new customer creation
			*/
	        $customerDetails = RedBeanHelper::export($customer->unbox(),['Status','DateModified','DateCreated','ActualPassword','Password']);
			
			$customerDetails['CustomerId'] 	= $customerDetails['id'];
			$response->returnedObject 		= $customerDetails;
	        $response->addNotification("Customer has been created successfully");
	        echo $response;
		}
		else {
			/** 
			* Some error has occurred while creating receipts
			*/
			throw new ApiException("An error occurred while processing", ErrorCodeType::ErrorInProcessing);
		}
    }
    catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }
});
/**
 * New user creation with tracking
 * POST /v1/customerstracking
 */
$app->post('/customerstracking', function () use ($app) {

    try {

        // Create a http request
        $req = $app->request();

        /**
         * Get a new user account
         * @var Model_Customers $user
         */
        $customer				= R::dispense('customers');
		$customer->CityId 		= $req->params('CityId');
		$customer->UserTypeId 	= $req->params('UserTypeId');
	    /**
         * Create the account
         */
	    $trackingId = $customer->customerTracking();
        /**
         * New user creation was made success
         */
		if($trackingId != ''){
	        $response = new beaconApiResponse();
	        $response->setStatus(HttpStatusCode::Created);
	        $response->meta->dataPropertyName = 'customer';
			/**
	        * returning upon repsonse of new customer creation
			*/
	        $response->addNotification("Customer tracking has been done successfully");
	        echo $response;
		}
		else {
			/** 
			* Some error has occurred while creating receipts
			*/
			throw new ApiException("An error occurred while processing", ErrorCodeType::ErrorInProcessing);
		}
    }
    catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }
});
/**
 * get city list and user types
 * GET /v1/usertypecities
 */
$app->get('/usertypecities', function () use ($app) {

    try {

        // Create a http request
        $req = $app->request();

        /**
         * Get city list
         * @var Model_Customers $cities
         */
        $cities		= R::dispense('customers');
	    /**
         * List the cities
         */
	    $cityList	= $cities->getCityUserTypesList();
        /**
         * city list was made success
         */
		if($cityList != ''){
	        $response = new beaconApiResponse();
	        $response->setStatus(HttpStatusCode::Created);
	        $response->meta->dataPropertyName = 'CityUserTypes';
			/**
	        * returning upon repsonse of city list
			*/
			$response->returnedObject 		= $cityList;
	        $response->addNotification("Cities has been retrieved successfully");
	        echo $response;
		}
		else {
			/** 
			* Some error has occurred while creating receipts
			*/
			throw new ApiException("An error occurred while processing", ErrorCodeType::ErrorInProcessing);
		}
    }
    catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }
});
/**
 * Start the Slim Application
 */

$app->run();