<?php

/**
 * Users endpoint
 * /v1/beacons
 *
 * @author 
 */

/**
 * Load configuration
 */
require_once('../../config.php');

/**
 * Load models
 */
require_once '../../lib/ModelBaseInterface.php';          // base interface class for RedBean models
require_once '../../lib/Model_Beacons_v2.php';            // beacon model

/**
 * Library objects
 */
use RedBean_Facade as R;
use Helpers\RedBeanHelper as RedBeanHelper;
use Helpers\PasswordHelper as PasswordHelper;
use Enumerations\HttpStatusCode as HttpStatusCode;
use Exceptions\ApiException as ApiException;
use Enumerations\AccountType as AccountType;
use Enumerations\StatusType as StatusType;
use Enumerations\ErrorCodeType as ErrorCodeType;
/**
 * Initialize application
 */
beaconApi::init(true);
$app = new \Slim\Slim();

/**
 * get beacon list in
 * GET /v1/beacons
 */
$app->get('/', beaconApi::checkToken(), function () use ($app) {

    try {

        // Create a http request
        $req 		= $app->request();
		$ownerId	= beaconApi::$resourceServer->getOwnerId();
        /**
         * Get beacon list
         * @var Model_Beacons 
         */
		$language		=	'en';
		$beacons				= 	R::dispense('beacons');
		if($req->params('Language'))
			$language			=	$req->params('Language');
		if($req->params('Latitude'))
			$beacons->Latitude	=	$req->params('Latitude');
		if($req->params('Longitude'))
			$beacons->Longitude	=	$req->params('Longitude');
		if($req->params('Store'))
			$beacons->Store		=	$req->params('Store');
		
		$beacons->UserId		=	$ownerId;
		$beacons->Language		=	$language;
		$beaconLists  			=  	$beacons->getBeaconList();
		$response 				= 	new beaconApiResponse();
	   	if(is_array($beaconLists)){
			$response->setStatus(HttpStatusCode::Ok);
			$response->meta->dataPropertyName = 'BeaconList';
			/**
	        * returning upon repsonse of beacon list
			*/
			$response->returnedObject = $beaconLists['BeaconList'];
		  	$response->addNotification('Beacon list retrieved successfully');
		}
        else{
			/** 
			* Error in Getting Beacon list
			*/
			
			$response->setStatus(HttpStatusCode::Ok);
			$response->meta->dataPropertyName = 'BeaconList';
			/**
	        * returning upon repsonse of beacon list
			*/
			$response->returnedObject = (object)[];
		  	$response->addNotification('No Result Found');
			
			
			// throw new ApiException("No Beacons found",ErrorCodeType::NoResultFound);
		}
        echo $response;
    }
    catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }
});


/**
 * get beacon list in
 * GET /v1/beacons
 */
$app->get('/test',beaconApi::checkToken(), function () use ($app) {
try {

       // Create a http request
       $req 		= $app->request();
	   $customerId = beaconApi::$resourceServer->getOwnerId();
       $beaconLists = '';
	   	if(is_array($beaconLists)){
			$response->setStatus(HttpStatusCode::Ok);
			$response->meta->dataPropertyName = 'BeaconList';
			/**
	        * returning upon repsonse of beacon list
			*/
			$response->returnedObject = $beaconLists['BeaconList'];
		  	$response->addNotification('Beacon list retrieved successfully');
		}
        else{
			/** 
			* Error in Getting Beacon list
			*/
			throw new ApiException("No Beacons found",ErrorCodeType::NoResultFound);
		}
        echo $response;
    }
    catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }
});
/**
 * edit angles
 * PUT /v1/beacons/{BEACONID}/angles/{ANGLEID}
 */
$app->put('/:beaconId/angles/:angleId',beaconApi::checkToken(), function ($beaconId,$angleId) use ($app) {

     try{
	 	
	 	$angleOne	=	$angleOneDescription	=  $angleOneDescriptionFR = '';
		$angleTwo	=	$angleTwoDescription	=  $angleTwoDescriptionFR = '';
		$angleThree	=	$angleThreeDescription	=  $angleThreeDescriptionFR = '';
		$angleFour	=	$angleFourDescription	=  $angleFourDescriptionFR = '';
        // Create a http request
        $request 		= $app->request();
    	$body 			= $request->getBody();
		$requestedById 	= beaconApi::$resourceServer->getOwnerId();
    	$input			= json_decode($body);
		/**
        * Get a angle details
		* Model_Beacons
		*/
		$angles 						= R::dispense('beacons');
		$angles->AngleId				= $angleId;
		$angles->BeaconId				= $beaconId;
		$angles->UserId					= $requestedById;
		$angles->AngleData				= $input;
		
		$updateAngle 					= $angles->updateAngles();
        if(!$updateAngle){
			/** 
			* Some error has occurred while updaing angles
			*/
			throw new ApiException("An error occurred while updating angles", ErrorCodeType::ErrorInProcessing);
        }
		else {
			 /**
	         * angles update was made success
	         */
			$response = new beaconApiResponse();
	        $response->setStatus(HttpStatusCode::Ok);
	        $response->meta->dataPropertyName = 'angles';
			/**
	        * returning upon repsonse 
			*/
			$response->addNotification('Angle has been updated successfully');
			echo $response;
		}
    }
     catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }

});

/**
 * New user creation
 * POST /v1/beacons/systemtracking
 */
$app->post('/systemtracking', function () use ($app) {

    try {

        // Create a http request
        $req = $app->request();

        /**
         * Get a new user account
         * @var Model_Customers $user
         */
        $beacons				= R::dispense('beacons');
		$beacons->DeviceId 		= $req->params('DeviceId');
		$beacons->Major 		= $req->params('Major');
		$beacons->Minor 		= $req->params('Minor');
		$beacons->MatchAngle 	= $req->params('MatchAngle');
	    /**
         * Create the account
         */
	    $trackId 	= $beacons->create();
        /**
         * New user creation was made success
         */
		if($trackId != ''){
	        $response = new beaconApiResponse();
	        $response->setStatus(HttpStatusCode::Created);
	        $response->meta->dataPropertyName = 'systemTracking';
	        $response->meta->systemTrackingId = $trackId;
	        $response->addNotification("System tracking has been added successfully");
	        echo $response;
		}
		else {
			/** 
			* Some error has occurred while creating receipts
			*/
			throw new ApiException("An error occurred while processing", ErrorCodeType::ErrorInProcessing);
		}
    }
    catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }
});
/**
 * get beacon list in
 * GET /v1/beacons
 */
$app->get('/beaconlist',  function () use ($app) {

    try {

        // Create a http request
        $req 		= $app->request();
        /**
         * Get beacon list
         * @var Model_Beacons 
         */
		$language		=	'en';
		$beacons		= 	R::dispense('beacons');
		if($req->params('Language'))
			$language			=	$req->params('Language');
		if($req->params('Latitude'))
			$beacons->Latitude	=	$req->params('Latitude');
		if($req->params('Longitude'))
			$beacons->Longitude	=	$req->params('Longitude');
		if($req->params('Store'))
			$beacons->Store		=	$req->params('Store');
		if($req->params('UserId'))
			$beacons->UserId		=	$req->params('UserId');
		if($req->params('Start'))
			$beacons->Start 		= $req->params('Start');	
		$beacons->Language		=	$language;
		$beaconLists  			=  	$beacons->getBeaconList();
		$response 				= 	new beaconApiResponse();
	   	if(is_array($beaconLists)){
			$response->setStatus(HttpStatusCode::Ok);
			$response->meta->dataPropertyName 		= 'BeaconList';
			$response->meta->totalVirtualBeacon 	= (int)$beaconLists['TotalVirtualBeacons'];
			$response->meta->listedVirtualBeacon 	= count($beaconLists['BeaconList']['virtualBeacons']);
			/**
	        * returning upon repsonse of beacon list
			*/
			$response->returnedObject = $beaconLists['BeaconList'];
		  	$response->addNotification('Beacon list retrieved successfully');
		}
        else{
			/** 
			* Error in Getting Beacon list
			*/
			
			$response->setStatus(HttpStatusCode::Ok);
			$response->meta->dataPropertyName = 'BeaconList';
			/**
	        * returning upon repsonse of beacon list
			*/
			$response->returnedObject = (object)[];
		  	$response->addNotification('No Result Found');
			
			
			// throw new ApiException("No Beacons found",ErrorCodeType::NoResultFound);
		}
        echo $response;
    }
    catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }
});

/**
* update battery power
* PUT /v1/beacons/{BEACONID}
 */
$app->put('/:beaconId', function ($beaconId) use ($app){
	try{
        // Create a http request
        $request 		= $app->request();
    	$body 			= $request->getBody();
    	$input			= json_decode($body);
		
		/**
        * Get a angle details
		* Model_Beacons
		*/
		$beacons 						= R::dispense('beacons');
		$beacons->id					= $beaconId;
		if(isset($input->BatteryPower) && $input->BatteryPower != '')
			$beacons->BatteryPower		= $input->BatteryPower;
		
		$updatePower 					= $beacons->updateBatteryPower(); 
        if(!$updatePower){
			/** 
			* Some error has occurred while updaing angles
			*/
			throw new ApiException("An error occurred while updating angles", ErrorCodeType::ErrorInProcessing);
        }
		else {
			 /**
	         * angles update was made success
	         */
			$response = new beaconApiResponse();
	        $response->setStatus(HttpStatusCode::Ok);
	        $response->meta->dataPropertyName = 'Battery Power';
			/**
	        * returning upon repsonse 
			*/
			$response->addNotification('Battery Power has been updated successfully');
			echo $response;
		}
    }
     catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }
});

/**
 * get beacon list in
 * GET /v1/beacons
 */
$app->get('/newbeaconlist',  function () use ($app) {

    try {

        // Create a http request
        $req 		= $app->request();
        /**
         * Get beacon list
         * @var Model_Beacons 
         */
		$language		=	'en';
		$beacons		= 	R::dispense('beacons');
		if($req->params('Language'))
			$language			=	$req->params('Language');
		if($req->params('Latitude'))
			$beacons->Latitude	=	$req->params('Latitude');
		if($req->params('Longitude'))
			$beacons->Longitude	=	$req->params('Longitude');
		if($req->params('UUID'))
			$beacons->UUID		=	$req->params('UUID');
		if($req->params('Major'))
			$beacons->Major	=	$req->params('Major');
		if($req->params('Minor'))
			$beacons->Minor	=	$req->params('Minor');
		if($req->params('Store'))
			$beacons->Store		=	$req->params('Store');
		if($req->params('UserId'))
			$beacons->UserId		=	$req->params('UserId');
		if($req->params('Start'))
			$beacons->Start 		= $req->params('Start');	
		$beacons->Language		=	$language;
		$beaconLists  			=  	$beacons->getBeaconList();
		$response 				= 	new beaconApiResponse();
	   	if(is_array($beaconLists)){
			$response->setStatus(HttpStatusCode::Ok);
			$response->meta->dataPropertyName 		= 'BeaconList';
			$response->meta->totalVirtualBeacon 	= (int)$beaconLists['TotalVirtualBeacons'];
			$response->meta->listedVirtualBeacon 	= count($beaconLists['BeaconList']['virtualBeacons']);
			/**
	        * returning upon repsonse of beacon list
			*/
			$response->returnedObject = $beaconLists['BeaconList'];
		  	$response->addNotification('Beacon list retrieved successfully');
		}
        else{
			/** 
			* Error in Getting Beacon list
			*/
			
			$response->setStatus(HttpStatusCode::Ok);
			$response->meta->dataPropertyName = 'BeaconList';
			/**
	        * returning upon repsonse of beacon list
			*/
			$response->returnedObject = (object)[];
		  	$response->addNotification('No Result Found');
			
			
			// throw new ApiException("No Beacons found",ErrorCodeType::NoResultFound);
		}
        echo $response;
    }
    catch (ApiException $e){
        // If occurs any error message then goes here
        beaconApi::showError(
            $e,
            $e->getHttpStatusCode(),
            $e->getErrors()
        );
    }
    catch (\Slim\Exception\Stop $e){
        // If occurs any error message for slim framework then goes here
    }
    catch (Exception $e) {
        // If occurs any error message then goes here
        beaconApi::showError($e);
    }
});


/**
 * Start the Slim Application
 */

$app->run();